@@ -145,16 +145,11 @@ def replaceTemplate4GATK(dist):
                                    'processing-for-variant-discovery-gatk4.hg38.wgs.inputs.json'))
 
     # main.sh2
-    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels', 'haplotypecaller-gvcf-gatk4-main.sh'))
+    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels', 'main.sh'))
     # inputs2
     _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels','src',
                            'haplotypecaller-gvcf-gatk4.hg38.wgs.inputs.json'))
 
-    # main.sh3
-    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels', 'joint-discovery-gatk4-main.sh'))
-    # inputs3
-    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels', 'src',
-                                   'joint-discovery-gatk4.hg38.wgs.inputs.json'))
 
 
 def replaceTemplate4WDL(dist):
@@ -172,6 +167,8 @@ def _replace_template(p):
 
     bucket = TEMPLATE_GATK_BUCKETS.get(config.getRegion())
 
+    oss_path = config.get_oss_path()
+
     if not bucket:
         raise Exception("This region do not support WDL")
 
@@ -189,5 +186,7 @@ def _replace_template(p):
 
         str = str.replace('#{{GENOMICS_PUBLIC_BUCKET}}', bucket)
 
+        str = str.replace('#{{DEFAULT_OSS_PATH}}', oss_path)
+
     with open(p, 'w') as f:
         f.write(str)
