@@ -123,7 +123,7 @@ def getJSON():
         'create_cluster': {
             'description': 'create cluster',
             'option': {
-                'image': "optional, imageId, type '%s t' for more" % CMD,
+                'image': "optional, imageId, type '%s i' for more" % CMD,
                 'type': "optional, instanceType, type '%s t' for more" % (CMD),
                 'nodes': "optional, int, default: 1",
                 #'groups': "optional, format: <groupName>[:type=<instanceType>][:nodes=<instanceCount>], default:group1",
@@ -158,7 +158,8 @@ def getJSON():
                 'vpc_cidr_block': 'CIDR, such as: 192.168.0.0/16',
                 'vpc_id': 'set VPC id',
                 'show_json': 'optional, just output cluster json, won\'t create a cluster, default: false',
-                'filePath': 'submit with a cluster description json file, other options are invalid'
+                'file_path': 'submit with a cluster description json file, other options are invalid',
+                'schedule_type': 'set job schedule type, scope: LowLatency, Poll, Push'
             }
         },
         'delete_cluster': {
@@ -182,7 +183,8 @@ def getJSON():
                                              and it is always using with nas_access_group and nas_file_system.
                                              example2: oss://path/to/mount/:/home/admin/dir/,
                                              and file is also supported: oss://path/to/mount/a.txt:/home/admin/dir/a.txt.""",
-                'image': "optional, imageId, type '%s t' for more" % CMD,
+                'image': "optional, imageId, type '%s i' for more" % CMD,
+                'type': "optional, instance type, type '%s t' for more" % CMD,
                 'show_json': 'optional, just output cluster json, won\'t create a cluster, default: false'
             }
         },
@@ -194,7 +196,7 @@ def getJSON():
                 'docker': """optional,optional, use docker, format: <docker_image_name>@<docker_storage_oss_path>,
                                           example: localhost:5000/myubuntu@oss://bucket/dockers/
                                           or for short: myubuntu@oss://bucket/dockers/ """,
-                'image': "optional, imageId, type '%s t' for more" % CMD,
+                'image': "optional, imageId, type '%s i' for more" % CMD,
 
 
                 'type': "optional, instanceType, type '%s t' for more , format:  {defaultValue}:{overwritable}:{desc}" % (CMD),
@@ -223,7 +225,7 @@ def getJSON():
                 'docker': """optional,optional, use docker, format: <docker_image_name>@<docker_storage_oss_path>,
                                       example: localhost:5000/myubuntu@oss://bucket/dockers/
                                       or for short: myubuntu@oss://bucket/dockers/ """,
-                'image': "optional, imageId, type '%s t' for more" % CMD,
+                'image': "optional, imageId, type '%s i' for more" % CMD,
 
                 'daemonize': 'When the application is executed, whether to restart each time. default：false',
                 'description': 'optional, description of the App',
@@ -331,6 +333,10 @@ def getJSON():
                                              and it is always using with nas_access_group and nas_file_system.
                                              example2: oss://path/to/mount/:/home/admin/dir/,
                                              and file is also supported: oss://path/to/mount/a.txt:/home/admin/dir/a.txt.""",
+                'log_mapping': """optional, the local log file to the oss directory mapping (When the program is running, the files written to the local directory will be uploaded to the corresponding oss_path),
+                                             format: <oss_path>:<file_path>[,<oss_path2>:<file_path2>...],
+                                             such as: oss://bucket/key/:/home/admin/mylog.txt
+                                             Note that the local file to the oss directory mapping, oss directory must ends with '/'.""",
                 'docker': """optional,optional, use docker, format: <docker_image_name>@<docker_storage_oss_path>,
                                              example: localhost:5000/myubuntu@oss://bucket/dockers/
                                              or for short: myubuntu@oss://bucket/dockers/ """,
