@@ -173,7 +173,8 @@ def __get_json():
                 'vpc_cidr_block': 'IP网段,如: 192.168.0.0/16',
                 'vpc_id': '设置 VPC id',
                 'show_json': '只显示cluster json不创建',
-                'filePath': '通过集群描述json文件提交,其他options将失效'
+                'file_path': '通过集群描述json文件提交,其他options将失效',
+                'schedule_type': '设置作业调度类型，可选范围: LowLatency, Poll, Push'
             }
         },
         'delete_cluster': {
@@ -194,6 +195,7 @@ def __get_json():
         如: nas://path/to/mount:/home/admin/nasdir 表示将NAS路径挂载到本地目录。
         使用NAS挂载还需配置nas_access_group和nas_file_system""",
                 'image': "可选, imageId, 更多信息输入 %s i 查看" % CMD,
+                'type': "可选, instanceType, 更多信息输入 %s t 查看" % CMD,
                 'show_json': '只显示cluster json不创建'
             }
 
@@ -327,12 +329,16 @@ def __get_json():
                                              挂载文件例子: oss://bucket/key1:/home/admin/key1 表示将oss的文件挂载为本地文件""",
                 'write_mount': """可选,可写模式挂载配置(任务结束后写到本地目录的文件会被上传到相应的oss_path下),
                                              格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
-                                             如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录""",
+                                             如: oss://bucket/key/:/home/admin/ossdir/ 表示将oss的路径挂载到本地目录""",
                 'mount': """可选,读写模式挂载NAS配置或者只读方式挂载OSS, 格式: <nas_path|oss_path>:<dir_path>[,<nas_path2|oss_path2>:<dir_path2>...],
                                              如: nas://path/to/mount/:/home/admin/nasdir/ 表示将NAS路径挂载到本地目录。
                                              使用NAS挂载还需配置nas_access_group和nas_file_system。
                                              如: oss://path/to/mount/:/home/admin/nasdir/ 表示将OSS路径挂载到本地目录,
                                              也支持直接挂载文件, 如:oss://path/to/mount/a.txt:/home/admin/nasdir/a.txt。""",
+                'log_mapping': """可选,日志映射配置(程序运行时写到本地目录的文件会被上传到相应的oss_path下),
+                                             格式: <oss_path>:<file_path>[,<oss_path2>:<file_path2>...],
+                                             如: oss://bucket/key/:/home/admin/mylog.txt
+                                             注意是本地文件到oss目录的映射，oss目录要以/结尾""",
                 'docker': """可选, 使用docker镜像运行, 格式: <image_name>@<storage_oss_path>,
                                              如: localhost:5000/myubuntu@oss://bucket/dockers/
                                              或者: myubuntu@oss://bucket/dockers/""",
